% Script/Function Description:
%   Script which defines simulation constants


%------------------------------------------------------------------------------
% Sampling rate variables and simulation time
%------------------------------------------------------------------------------
constants.Fs  = 100;                % Sample frequency (Hz)
constants.dt  = 1/constants.Fs;     % Sample interval (sec)
constants.t_start = 0;              % Simulation start time (sec)
constants.t_end = 180;              % Simulation end time (sec)
%------------------------------------------------------------------------------
% Earth model parameters
%------------------------------------------------------------------------------
constants.w_ie = 72.92115167e-6;    % WGS84 Earth rate (rad/s)
constants.mu = 3.986004418e14;      % Earth's gravitational constant (m^3/s^2)
constants.J2 = 1.082627e-3;         % Earth's second gravitational constant
constants.R0 = 6378137.0;           % Earth's equatorial radius (meters)
constants.Rp = 6356752.3142;        % Earth's polar radius (meters)
constants.e = 0.0818191908425;      % Eccentricity
constants.f = 1 / 298.257223563;    % Flattening from page 38 of text

%--------------------------------------------------------------------------
% IMU error characterization values - KVH 1750 IMU
%++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
% Gyro specific terms

% Bias terms
constants.gyro.b_g_FB = ??;      % Bias - Fixed Bias term (rad/s)
constants.gyro.b_g_BS = ??;  % Bias - Bias Stability Bias term (rad/s)
constants.gyro.b_g_BI_sigma = ??;  % Bias - Bias Instability Bias term 1-sigma (rad/s)
constants.gyro.BI.correlation_time = ??; % Correlation time for the bias instability (sec)

% Noise terms
constants.gyro.ARW = ??;      % Gyro Angle Random Walk (deg/rt-hr)

% Scale factor stability & misalignment terms
s_g_x = ?? * 1e-6;             % x-axis scale factor error (ppm * 1e-6)
s_g_y = ?? * 1e-6;             % y-axis scale factor error (ppm * 1e-6);
s_g_z = ?? * 1e-6;             % z-axis scale factor error (ppm * 1e-6);

m_g_xy =  1.0e-3;               % Misalignment of y-axis into x-axis (in rad)
m_g_xz =  0.5e-3;               % Misalignment of z-axis into x-axis
m_g_yx = -1.0e-3;               % Misalignment of x-axis into y-axis
m_g_yz =  0.2e-3;               % Misalignment of z-axis into y-axis
m_g_zx = -0.5e-3;               % Misalignment of x-axis into z-axis
m_g_zy =  0.7e-3;               % Misalignment of y-axis into z-axis

constants.gyro.M_g = ...
   [s_g_x , m_g_xy, m_g_xz; ... % The combined Misalignment / Scale Factor matrix (dimensionless)
    m_g_yx, s_g_y , m_g_yz; ...
    m_g_zx, m_g_zy, s_g_z ];
   
g_sens = ??;  % Gyro G-sensitivity (rad/sec/g)

constants.gyro.G_g = ...        % The gyro G-sensitivity matrix (rad/sec/g)
   [g_sens , 0      , 0; ...    
    0      , g_sens , 0; ...
    0      , 0      , g_sens ];

%++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
% Accelerometer specific terms

% Bias terms
constants.accel.b_a_FB = ??;     % Bias - Fixed Bias term (m/s^2)
constants.accel.b_a_BS = ??;  % Bias - Bias Stability Bias term (m/s^2)
constants.accel.b_a_BI_sigma = ??;  % Bias - Bias Instability Bias term 1-sigma (m/s^2)
constants.accel.BI.correlation_time = ??; % Correlation time for the bias instability (sec)

% Noise terms
constants.accel.VRW = ??;     % Accel Angle Random Walk ((m/s^2)/rt-Hz)

% Scale factor stability & misalignment terms
s_a_x = ?? * 1e-6;             % x-axis scale factor error (ppm * 1e-6)
s_a_y = ?? * 1e-6;             % y-axis scale factor error (ppm * 1e-6);
s_a_z = ?? * 1e-6;             % z-axis scale factor error (ppm * 1e-6);

m_a_xy = -1.0e-3;               % Misalignment of y-axis into x-axis (in rad)
m_a_xz =  0.1e-3;               % Misalignment of z-axis into x-axis
m_a_yx =  0.5e-3;               % Misalignment of x-axis into y-axis
m_a_yz =  1.0e-3;               % Misalignment of z-axis into y-axis
m_a_zx =  0.5e-3;               % Misalignment of x-axis into z-axis
m_a_zy = -0.5e-3;               % Misalignment of y-axis into z-axis

constants.accel.M_a = ...
   [s_a_x , m_a_xy, m_a_xz; ... % The combined Misalignment / Scale Factor matrix (dimensionless)
    m_a_yx, s_a_y , m_a_yz; ...
    m_a_zx, m_a_zy, s_a_z ];
